@@ -67,18 +67,18 @@ plot.evfit <- function(x, legend = TRUE, col = 1, extreme = x$extreme,
   dist <- names(x[["parameters"]])
   # if there's more than one distribution to fit, ignore user specified color
   if (length(dist) > 1) col <- seq_along(dist)
-  ylim <- if(is.null(ylim)) c(0, max(x$values)) else ylim
+  ylim <- if(is.null(ylim)) c(0, max(x$values, na.rm = TRUE)) else ylim
 
   # plot obersvations (points)
   if (log) {
     if(is.null(xlab)) xlab <- expression("Reduced variate,  " * -log(-log(italic(F))))
     evplot(x$values, xlab = xlab, ylab = ylab, col = col[1], rp.axis = FALSE,
-           ylim = ylim)
+           ylim = ylim, ...)
   } else {
     if(is.null(xlab)) xlab <- freq.lab
     plot(gringorten(x$values), x$values, col = col[1],
          xlim = c(0, 1), ylim = ylim,
-         xlab = xlab, ylab = ylab)
+         xlab = xlab, ylab = ylab, ...)
   }
 
 
@@ -414,7 +414,7 @@ evfit <- function (x, distribution, zeta = NULL,
   is.censored <- FALSE
 
   # are there obervations with flow = 0?
-  is.zero <- x == 0
+  is.zero <- as.vector(is.finite(x) & x == 0)
   if (sum(is.zero) > 1) {
     is.censored <- TRUE
 
@@ -619,6 +619,42 @@ tyearsS <- function (lfobj, event = 1 / probs, probs = 0.01, pooling = NULL,
 
 
 # Regional frequency analysis ----
+#' Regional Frequency Analysis
+#'
+#' This function uses J.R.M. Hosking's package produce an object of class
+#' \code{'rfd'}, containing the specification of the regional frequency distribution.
+#'
+#' @param lflist A list of \code{'lfobj'}s.
+#' @param n \acronym{MAM}-n is used (e.g. n=7 means \acronym{MAM}7).
+#' @param event A value for T, e.g. event = 100 means the 100 years extreme low flow event.
+#' @param dist A vector of distribution to fit, the names are according to
+#' Hosking's in his \pkg{lmom} package. Can be an of  \code{"wei"}, \code{"gev"},
+#' \code{"ln3"}, \code{"gum"}, \code{"pe3"}.
+#'
+#' @references Gustard, A. & Demuth, S. (2009) (Eds) Manual on Low-flow Estimation
+#' and Prediction. Operational Hydrology Report No. 50, \acronym{WNO}-No. 1029, 136p.
+#' \url{https://library.wmo.int/doc_num.php?explnum_id=7699}
+
+#' @seealso \code{\link{regfit}} and \code{\link{lmom-package}} which this function wraps.
+#'
+#' @keywords Regional Frequency Analysis
+#'
+#' @examples
+#' data(ngaruroro)
+
+#' # Toy example to get some more "rivers"
+#' seventies <- subset(ngaruroro, hyear %in% 1970:1979)
+#' eighties <- subset(ngaruroro, hyear %in% 1980:1989)
+#' nineties <- subset(ngaruroro, hyear %in% 1990:1999)
+#'
+#' toyrfa <- rfa(list(seventies,eighties,nineties), n=3,dist = "gev")
+#'
+# Now you can work on using Hoskings lmomRFA-package, e.g.
+#' require(lmomRFA)
+#' regquant(c(1/1000,1/100),toyrfa)
+#' sitequant(1/100,toyrfa)
+
+#' @inherit lmomRFA::regfit return
 rfa <- function(lflist, n = 7, event = 100,
                 dist =  c("wei", "gev", "ln3", "gum", "pe3")){
   lapply(lflist, lfcheck)
@@ -634,6 +670,36 @@ rfa <- function(lflist, n = 7, event = 100,
   return(rfit)
 }
 
+
+#' Regional Frequency Analysis
+#'
+#' This function uses J.R.M. Hosking's package \pkg{lmom} to produce a L-moment diagram.
+#'
+#' @param lflist A list of \code{'lfobj'}s.
+#' @param n \acronym{MAM}-n is used (e.g. n=7 means \acronym{MAM}7).
+#'
+#' @references Gustard, A. & Demuth, S. (2009) (Eds) Manual on Low-flow Estimation
+#' and Prediction. Operational Hydrology Report No. 50, \acronym{WNO}-No. 1029, 136p.
+#' \url{https://library.wmo.int/doc_num.php?explnum_id=7699}
+
+#' @seealso \code{\link{lmrd}} and \code{\link{lmom-package}} which this function wraps.
+#'
+#' @keywords Regional Frequency Analysis
+#'
+#' @examples
+#' data(ngaruroro)
+
+#' # Toy example to get some more "rivers"
+#' seventies <- subset(ngaruroro, hyear %in% 1970:1979)
+#' eighties <- subset(ngaruroro, hyear %in% 1980:1989)
+#' nineties <- subset(ngaruroro, hyear %in% 1990:1999)
+#'
+#' rfaplot(list(seventies, eighties, nineties), n = 3)
+
+#' @inheritDotParams lmom::lmrd
+#' @inherit lmom::lmrd return
+
+
 rfaplot <- function(lflist, n = 7, ...){
   lapply(lflist, lfcheck)
 
